package com.zksy.infrared.service;

import com.zksy.infrared.domain.InfraredReadingMeter;
import com.baomidou.mybatisplus.extension.service.IService;
import com.zksy.infrared.domain.vo.MeterDayDataVo;
import com.zksy.infrared.domain.vo.MeterMonthDataVo;
import com.zksy.infrared.domain.vo.MeterQuarterDataVo;
import com.zksy.infrared.domain.vo.MeterYearDataVo;

import java.util.List;
import java.util.Map;

/**
* @author Administrator
* @description 针对表【infrared_reading_meter(红外读电表数据)】的数据库操作Service
* @createDate 2025-06-06 10:27:47
*/
public interface InfraredReadingMeterService extends IService<InfraredReadingMeter> {

    MeterYearDataVo selectByYear(Integer year,String meterNumber);

    MeterMonthDataVo selectByYearselectByYearAndMonthWithDayData(Integer year, Integer month, String meterNumber);

    MeterDayDataVo selectByNewestData(String meterNumber);

    MeterYearDataVo selectByCurrentYearData();

    MeterMonthDataVo selectByCurrentYearselectByCurrentYearAndCurrentMonthWithDayData();

    MeterQuarterDataVo selectByCurrentQuarterData();

    /**
     * 查询所有电表的「当日用电量」和「当前总用电量」，返回List<Map>
     * 排除电表号和耗电量为空的情况
     * @return 封装结果的Map列表
     */
    List<Map<String, Object>> getDailyAndTotalElectricityAsMap();
}
